<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nk="http://netkernel.org">
  <xsl:output method="xml"/>

	<xsl:param name="resultsets" nk:class="java.lang.String"/>


	<xsl:variable name="yscale" select="250"/>
   	<xsl:variable name="xscale" select="350"/>
   	<xsl:variable name="offset" select="20"/>
   	
	<xsl:variable name="max" select="/times/max"/>
	<xsl:variable name="steps" select="count(/times//test) div $resultsets"/>
	<xsl:variable name="xstep" select="$xscale div $steps"/>
   	<xsl:variable name="xb" select="$offset"/>
   	<xsl:variable name="yb" select="$yscale+$offset"/>

    <xsl:template match="/times">
    	<svg
   xmlns:dc="http://purl.org/dc/elements/1.1/"
   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
   xmlns="http://www.w3.org/2000/svg"
   xmlns:xlink="http://www.w3.org/1999/xlink"
   width="{$xscale+2*$offset+70+10}"
   height="{$yscale+2*$offset+10}"
   version="1.0"
   >
   
  <defs
     id="defs4">
     <style type="text/css"><![CDATA[
      .labeltext {
      	fill:black;
      	stroke:none;
      	font-family:helvetica;
      	font-style:normal;
      	font-weight:bold;
      	font-size:12px;
      	fill-opacity:1;
      	stroke-opacity:1;
      	stroke-width:1pt;
      	stroke-linejoin:miter;
      	stroke-linecap:butt;
      	}
      .baselinefill {
      		fill:#00b700;
      		stroke:#00cd00;
      	}
      	.spacialfill {
      		fill:#b70000;
      		stroke:#cd0000;
      	}
      	
      	.localfill{
      		fill-opacity:0.2;fill-rule:evenodd;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:0.66666667
      		}
      	 
    ]]>
    </style>
   
    <linearGradient
       id="linearGradient3175">
      <stop
         style="stop-color:#c7d3b7;stop-opacity:1;"
         offset="0"
         id="stop3177" />
      <stop
         style="stop-color:#c7d3b7;stop-opacity:0;"
         offset="1"
         id="stop3179" />
    </linearGradient>
    <linearGradient
       xlink:href="#linearGradient3175"
       id="linearGradient3181"
       x1="0"
       y1="{2*$offset+$yscale}"
       x2="{2*$offset+$xscale}"
       y2="0"
       gradientUnits="userSpaceOnUse"
       gradientTransform="matrix(1.0350812,0,0,1.4812778,-3.511396,-28.988847)" />
  </defs>
  
  <g
     id="layer1">
     <!--
       *********
       DRAW FRAME / AXES
       *********
       -->
    <rect
       style="fill:url(#linearGradient3181);fill-opacity:1;stroke:#bdbdbd;stroke-width:1.23824191;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
       id="frame"
       width="{$xscale+2*$offset+70}"
       height="{$yscale+2*$offset}"
       x="0"
       y="0" />
    <path
       style="fill:none;fill-rule:evenodd;stroke:#000000;stroke-width:0.90433878px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
       d="M {$offset},{$offset} L {$offset},{$offset+$yscale} L {$offset+$xscale}, {$offset+$yscale}"
       id="axes" />
	<text
		class="labeltext"
		x="0"
		y="{$offset - 5}"
		id="ytitle">
			<tspan><xsl:value-of select="round($max div 1000)"/>s</tspan>
	</text>
	   <!--
       *********
       DRAW CHARTS
       *********
       -->
       <path
       class="localfill spacialfill"
       id="alloc">
       <xsl:attribute name="d">
       		<xsl:call-template name="drawcurve">
       			<xsl:with-param name="element" select="'EXTRINSIC-SPACIAL'"/>
       		</xsl:call-template>
       </xsl:attribute>
       </path>
       <path
       class="localfill baselinefill"
       id="baseline">
       <xsl:attribute name="d">
       		<xsl:call-template name="drawcurve">
       			<xsl:with-param name="element" select="'LOCAL'"/>
       		</xsl:call-template>
       </xsl:attribute>
       </path>
       
       <!--
       *********
       DRAW TITLE/LEGEND
       *********
       -->
       <text
		class="labeltext"
	       x="{$offset+$xscale+20}"
       		y="20"
	       id="title">
		<tspan id="tspan607">Subset Sum</tspan>
		</text>
		
		<rect
       class="localfill spacialfill"
       id="frame"
       width="10"
       height="10"
       x="{$offset+$xscale+20}"
       y="50" />
       <text
			class="labeltext"
	       x="{$offset+$xscale+35}"
       		y="60"
	       id="title">
		<tspan id="tspan607">spacial</tspan>
	   </text>
	   
       <rect
       class="localfill baselinefill"
       id="frame"
       width="10"
       height="10"
       x="{$offset+$xscale+20}"
       y="90" />
       <text
		class="labeltext"
	       x="{$offset+$xscale+35}"
       		y="100"
	       id="title">
		<tspan id="tspan607">local</tspan>
	   </text>
  </g>
</svg>
    </xsl:template>
    
    <xsl:template name="drawcurve">
    	<xsl:param name="element"/>
    	M <xsl:value-of select="$xb"/>, <xsl:value-of select="$yb"/>
       	<xsl:for-each select="/times//test[method=$element]">
       	<xsl:variable name="e" select="time"/>
       	<xsl:if test="position()=1">
       	L   <xsl:value-of select="$xb"/>, <xsl:value-of select="$yb - (($e div $max) * $yscale )"/>
       	</xsl:if>
       	L   <xsl:value-of select="$xb+(position()*$xstep)"/>, <xsl:value-of select="$yb - (($e div $max) * $yscale )"/>
       	<xsl:if test="position()=last()">
       	L   <xsl:value-of select="$xb+(position()*$xstep)"/>, <xsl:value-of select="$yb"/>
       	</xsl:if>
       	</xsl:for-each>
       	L <xsl:value-of select="$xb"/>, <xsl:value-of select="$yb"/> z
    </xsl:template>
    

</xsl:stylesheet>